import json
from datetime import datetime
import asyncio

from rosetta_dispatcher.aio_dispatch_client import AioDispatchClient


async def main():
    print('main1')
    host = '61.160.36.168'
    port = 4032
    dc = await AioDispatchClient.create(redis_host=host, redis_port=port)

    data = {
        "source_language": "zh",
        "target_language": "en",
        "terminology_list": [
        ],
        "chapter_content": [
            ""
        ]
    }

    async def process():
        while True:
            # print('before process')
            start = datetime.utcnow()
            result = await dc.process(service_queue='NMT_RPC_QUEUE_DEV', data=json.dumps(data), timeout=100)
            end = datetime.utcnow()
            if not result:
               print(end - start, result)

    tasks = [process() for i in range(16)]
    await asyncio.wait(tasks)


futures = [main()]
loop = asyncio.get_event_loop()
loop.run_until_complete(asyncio.wait(futures))



from pydantic import BaseModel, Field

from rosetta_dispatcher.model.dispatch_types import DispatchRequestType, DispatchResponseStatus


class DispatchResponseModel(BaseModel):
    correlation_id: str = Field(None)
    status: DispatchResponseStatus = Field(DispatchResponseStatus.OK)
    data: str = Field(None)


import json
import redis

from rosetta_dispatcher import idtool
from rosetta_dispatcher.model.dispatch_response_model import DispatchResponseModel
from rosetta_dispatcher.model.dispatch_types import DispatchRequestType, DispatchResponseStatus


class DispatchClient:
    def __init__(self, redis_host: str, redis_port: int):
        self.redis_host = redis_host
        self.redis_port = redis_port
        self.pool = redis.ConnectionPool(host=redis_host, port=redis_port, decode_responses=True)

    def process(self, service_queue: str, data: str, timeout: int = 500):
        r = redis.Redis(connection_pool=self.pool)

        reply_to = idtool.gen_uuid()
        correlation_id = idtool.gen_uuid()
        request = {
            'content_type': DispatchRequestType.JSON,
            'reply_to': reply_to,
            'correlation_id': correlation_id,
            'timeout': timeout,
            'data': data
        }

        r.rpush(service_queue, json.dumps(request, ensure_ascii=False))
        result = r.blpop(reply_to, timeout=timeout)
        if result and result[0] == reply_to:
            response = DispatchResponseModel.parse_obj(json.loads(result[1]))
            if response.correlation_id == correlation_id and response.status == DispatchResponseStatus.OK:
                return response.data
        return None



import json
from datetime import datetime

from rosetta_dispatcher.dispatch_client import DispatchClient

host = '61.160.36.168'
port = 4032

dc = DispatchClient(redis_host=host, redis_port=port)

count = 0
data = {
    "source_language": "zh",
    "target_language": "en",
    "terminology_list": [
    ],
    "chapter_content": [
        "我的世界"
    ]
}
while True:
    start = datetime.utcnow()
    result = dc.process(service_queue='NMT_RPC_QUEUE_DEV', data=json.dumps(data), timeout=10)
    end = datetime.utcnow()
    print(end-start)
    print(result)
    count+=1